function [denoisedAudio] = denoiseSpeech (noisySpeech, cnn, targetsMean, targetsStd, noisyMean, noisyStd)
% denoiseSpeech: Devuelve el audio restaurado a partir de una seal ruidosa
% utilizando la CNN entrenada.
%
%   noisySpeech: Seal de audio con ruido.
%   cnn: Red neuronal convolucional.
%   targetsMean: Media de los audios limpios en la fase de entrenamiento.
%   targetsStd: Desviacin tpica de los audios limpios en la fase de entrenamiento.
%   noisyMean: Media de los audios con ruido en la fase de entrenamiento.
%   noisyStd: Desviacin tpica de los audios con ruido en la fase de entrenamiento.

% Parmetros de la STFT.
WindowLength  = 256; 
window        = hamming(WindowLength,'periodic');
Shift         = round(0.75 * WindowLength); % Encabalgamiento ventanas
nMagnitude    = WindowLength/2 + 1; % Vectores magnitud
nInputVectors = 8; % N vectores mag consecutivos en input

% Se extraen los vectores magnitud y fase del audio.
[noisyMag, noisyPhase] = computeStft(noisySpeech, window, Shift, WindowLength, nMagnitude); 
noisyMag = getInputVectors (noisyMag, nInputVectors, nMagnitude);

% Se normaliza la magnitud en funcin de los valores con los que la red ha
% sido entrenada.
noisyMag(:) = (noisyMag(:) - noisyMean) / noisyStd;

% Se dimensiona la magnitud para adaptarla al formato de entrada de la red.
input = adaptInputShape(noisyMag);

% Prediccin de los vectores magnitud de la seal restaurada.
denoisedStft = predict(cnn, input);

% Escalamos la salida en funcin de los valores con los que la red ha sido
% entrenada.
denoisedStft(:) = scaleOutput(denoisedStft, targetsMean, targetsStd);

% Se restaura la parte simtrica de la magnitud y se aade la informacin
% de fase.
denoisedStft = restoreStft(denoisedStft, noisyPhase);

% Clculo de la seal de audio restaurada.
denoisedAudio = computeIstft(denoisedStft, window, Shift, WindowLength);





