function [inputProcessedAudio, targetProcessedAudio, speechPhase] = featureTransform (speech, src)
% Preprocess: devuelve las STFT del audio y la matriz 129*8 del audio+ruido
%
%   speech: Seal de audio de entrada
%   src: Conversor de frecuencia de muestreo

% Parmetros de la STFT.
WindowLength  = 256; 
window        = hamming(WindowLength,'periodic');
Shift         = round(0.75 * WindowLength); % Encabalgamiento ventanas
nMagnitude    = WindowLength/2 + 1; % Vectores magnitud
nInputVectors = 8; % N vectores mag consecutivos en input

% Asegura que la longitud del audio es proporcional al factor de decimado
speech = audioLengthExtend(speech);

% Conversin fs
speech = src(speech);
reset(src);

% Se aade AWGN con SNR=0 a la seal de audio.
noisySpeech = awgn(speech, 0, 'measured');

% Clculo de la STFT para la seal original 
[speechSTFT, speechPhase] = computeStft(speech, window, Shift, WindowLength, nMagnitude);
targetProcessedAudio = speechSTFT;

% Clculo de la STFT para la seal con ruido y obtencin de la matriz de 
% prediccin.
noisySpeechSTFT = computeStft(noisySpeech, window, Shift, WindowLength, nMagnitude); 
inputProcessedAudio = getInputVectors (noisySpeechSTFT, nInputVectors, nMagnitude);



