function [denoisingCNN, inputsMean, inputsStd, targetsMean, targetsStd] = trainCNN ()
% trainCNN: Devuelve una CNN entrenada a partir de un set de entrenamiento.


% Se crea un datastore para almacenar los audios de entrenamiento
trainDs = getAudioData('train');

% Se utiliza un subconjunto del set de 1000 audios.
trainDs = subset(trainDs, 1:1250);

% Se crea un tall array para importar de forma parcial los audios en
% memoria.
t = tall(trainDs);

% Se define el conversor de fs
src = dsp.SampleRateConverter("InputSampleRate",16000, ...
                              "OutputSampleRate",8000, ...
                              "Bandwidth",7920);

% Preprocesamiento de los audios.                          
[inputs,targets] = cellfun(@(x)featureTransform(x, src),t,"UniformOutput",false);
[inputs, targets] = gather(inputs, targets);

% Normalizacin de los vectores magnitud.
[inputs, inputsMean, inputsStd]  = magNormalization(inputs);
[targets, targetsMean, targetsStd] = magNormalization(targets);

% Adaptacin al formato de entrada de la cnn.
inputs  = adaptInputShape(inputs);
targets = adaptTargetShape(targets);

% Se divide el set de entrenamiento en entrenamiento y validacin.
[trainInputs, trainTargets, validationInputs, validationTargets] = ...
    splitTrainToValidation(inputs, targets);

% Se definen los parmetros de la cnn.
[layers, options] = configureCNN (trainInputs, validationInputs, validationTargets);

% Entrenamiento de la cnn.
denoisingCNN = trainNetwork(trainInputs, trainTargets, layers, options);